<?php

namespace Drupal\simplenews_resend\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Access\AccessResultInterface;
use Drupal\Core\Routing\Access\AccessInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\node\NodeInterface;

/**
 * Checks if current user can reset newsletter status.
 *
 * Usage example:
 *
 * @code
 * entity.node.resend_status:
 *   path: '/node/{node}/resend'
 *   defaults:
 *     _entity_form: 'node.simplenews_resend'
 *     _title: 'Resend newsletter'
 *   requirements:
 *     _reset_newsletter_status: '{node}'
 * @endcode
 */
class ResetNewsletterStatusAccessChecker implements AccessInterface {

  /**
   * Checks access to the reset newsletter status page.
   *
   * @param \Drupal\node\NodeInterface $node
   *   The newsletter node that is being reset.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The currently logged in account.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function access(NodeInterface $node, AccountInterface $account): AccessResultInterface {
    if (simplenews_check_node_types($node->getType())) {
      if ($node->simplenews_issue->status == SIMPLENEWS_STATUS_SEND_READY) {
        return AccessResult::allowedIfHasPermission($account, 'reset simplenews status');
      }
    }

    return AccessResult::neutral();
  }

}
